DatabaseErrorInformation

Trait DatabaseErrorInformation 

pub trait DatabaseErrorInformation {
    // Required methods
    fn message(&self) -> &str;
    fn details(&self) -> Option<&str>;
    fn hint(&self) -> Option<&str>;
    fn table_name(&self) -> Option<&str>;
    fn column_name(&self) -> Option<&str>;
    fn constraint_name(&self) -> Option<&str>;
    fn statement_position(&self) -> Option<i32>;
}
Information about an error that was returned by the database.

Required Methods

fn message(&self) -> &str

The primary human-readable error message. Typically one line.

fn details(&self) -> Option<&str>

An optional secondary error message providing more details about the problem, if it was provided by the database. Might span multiple lines.

fn hint(&self) -> Option<&str>

An optional suggestion of what to do about the problem, if one was provided by the database.

fn table_name(&self) -> Option<&str>

The name of the table the error was associated with, if the error was associated with a specific table and the backend supports retrieving that information.

Currently this method will return None for all backends other than PostgreSQL.

fn column_name(&self) -> Option<&str>

The name of the column the error was associated with, if the error was associated with a specific column and the backend supports retrieving that information.

Currently this method will return None for all backends other than PostgreSQL.

fn constraint_name(&self) -> Option<&str>

The constraint that was violated if this error is a constraint violation and the backend supports retrieving that information.

Currently this method will return None for all backends other than PostgreSQL.

fn statement_position(&self) -> Option<i32>

An optional integer indicating an error cursor position as an index into the original statement string.